@@ -12,6 +12,7 @@ Example:
 
 """
 import logging
+from typing import Sequence
 
 import pytest
 import structlog
@@ -30,11 +31,11 @@ def log_level():  # pragma: no cover
 
 
 @pytest.fixture
-def log_processors(log_output):  # pragma: no cover
+def log_processors(log_output: LogCapture):  # pragma: no cover
     return [log_output]
 
 
 @pytest.fixture
-def configure_structlog(log_level, log_processors):  # pragma: no cover
-    processors = get_final_processors(log_level, log_processors)
+def configure_structlog(log_level: int, log_processors: Sequence[LogCapture]):  # pragma: no cover
+    processors = get_final_processors(log_level, log_processors)  # type: ignore
     structlog.configure(processors=processors)
