@@ -1,10 +1,13 @@
 """Interface to structlog."""
 
+from typing import Optional
+
 import structlog
+from outcome.logkit.types import StructLogger
 from outcome.utils import env
 
 
-def get_logger(name=None, *args, **kwargs):
+def get_logger(name: Optional[str] = None, *args: object, **kwargs: object) -> StructLogger:
     if not structlog.is_configured():
         raise Exception('Logger is not configured')
 
